---
title: 'antispam:plugin:dkim'
url: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-dkim'
markdown: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-dkim.md'
date: '2026-09-22'
description: 'Perform DKIM lookups as well as historical DomainKeys lookups. warden --task=antispam:plugin:dkim Option Value Default Description --dkim_timeout <string> 5 How many seconds to wait for a DKIM query to complete, before scanning continues without the DKIM result. A numeric value is optiona…'
taxonomy:
  category:
    - docs
  tag:
    - dkim
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Antispam       antispam:plugin:dkim    

# antispam:plugin:dkim

Perform DKIM lookups as well as historical DomainKeys lookups.

```
warden --task=antispam:plugin:dkim
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--dkim_timeout` | <string> | 5 | How many seconds to wait for a DKIM query to complete, before scanning continues without the DKIM result. A numeric value is optionally suffixed by a time unit (s, m, h, d, w, indicating seconds (default), minutes, hours, days, weeks). |
| `--welcomelist_from_dkim` | <string1,<string2> |  | Works similarly to welcomelist\_from, except that in addition to matching an author address (From) to the pattern in the first parameter, the message must also carry a Domain Keys Identified Mail (DKIM) signature made by a signing domain (SDID, i.e. the d= tag) that is acceptable to us. Only one whitelist entry is allowed per line, as in welcomelist\_from\_rcvd. Multiple welcomelist\_from\_dkim lines are allowed. File-glob style characters are allowed for the From address (the first parameter), just like with whitelist\_from\_rcvd. The second parameter does not accept wildcards. If no signing-domain parameter is specified, the only acceptable signature will be an Author Domain Signature (sometimes called first-party signature) which is a signature where the signing domain (SDID) of a signature matches the domain of the authors address (i.e. the address in a From header field). Since this whitelist requires a DKIM check to be made, network tests must be enabled. |
| `--whitelist_from_dkim` (SA 3.4) |  |  |  |
| `--welcomelist_from_dkim_add` | <string> |  | Add a single entry to welcomelist\_from\_dkim. |
| `--whitelist_from_dkim_add` (SA 3.4) |  |  |  |
| `--welcomelist_from_dkim_del` | <string> |  | Remove a single entry from whitelist\_from\_dkim. |
| `--whitelist_from_dkim_del` (SA 3.4) |  |  |  |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// set the dkim_timeout
warden --task=antispam:plugin:dkim --dkim_timeout=5 --reload=yes

// reset dkim_timeout to its default value
warden --task=antispam:plugin:dkim --default_option=dkim_timeout --reload=yes

// reset all settings to their default values
warden --task=antispam:plugin:dkim --default=yes --reload=yes
```

## Related Pages

- [DKIM Settings](https://docs.danami.com/warden/settings/antispam/plugin-settings/dkim "DKIM Settings")
- [DKIM](https://docs.danami.com/warden/user-guide/antispam-plugins/dkim "DKIM")

 [ ](https://docs.danami.com/warden/user-guide/antispam-plugins/dkim) [](https://docs.danami.com/warden/settings/antispam/plugin-settings/dkim)

---

## Navigation

- Previous: [antispam:plugin:decodeshorturls](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-decodeshorturls.md)
- Next: [antispam:plugin:extracttext](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-extracttext.md)
